'Writing PICAXE BASIC Code
'PICAXE Tutorial
'Experiment: PICAXE 08M2 Wi-Fi Communicator
'12 Dec 2015
'Schematic: PICAXE Wi-Fi Communicator.dch
'Code: PICAXE Wi-Fi Communicator.bas
'Overview: Read temperature from DS18B20 into an 08M2,connect an 08M2 to an ESP-01 for
'Wi-Fi operation, and send temperature to Thingspeak every 60 minutes.

#picaxe 08M2 'Identify the PICAXE being used as an 08M2.
#no_data 'Prevent data from being downloaded to PICAXE.
#terminal 4800 'Call terminal and set baud rate to 4800.
symbol temp=C.1 'DS18B20 should is connected to Pin C.1.
symbol CH_PD=C.2 'CH_PD pin on ESP-01 is connected to Pin C.2.
symbol baud=T2400_4 'Set baud rate for serout transmissions.
symbol temp_now = b4 'Symbol and storage location for temperature reading from DS18B20.

main:

check_temp:
readtemp C.1, temp_now 'Read temperature from DS18B20, and store it in temp_now.
bintoascii temp_now,b5,b6,b7 'Convert current temperature from binary to ASCII and 
'store it in b5,b6,b7.

ESP_On:
high CH_PD 'Enables ESP-01 module.
pause 1000 'Pause 1 second to allow ESP-01 to boot.

AT:
serout C.4,baud,("AT",13,10) 'Send attention command+CR+LF to ESP-01.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("AT OK",13,10)

CWQAP:
serout C.4,baud,("AT+CWQAP",13,10) 'Send disconnect from Wi-Fi command+CR+LF to ESP-01.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("QAP OK",13,10)

CWMODE:
serout C.4,baud,("AT+CWMODE_CUR=1",13,10) 'Send STA command+CR+LF to ESP-01.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("CWMODE OK",13,10)

'The "34" codes in the lines following send commas to separate the data for the ESP-01.
CWJAP:
serout C.4,baud,("AT+CWJAP_CUR=",34,"your SSID",34,",",34,"your password",34,13,10)
'Send command string to join LAN+SSID+LAN password+CR+LF to ESP-01.
serin[6000,send_fail],C.3,baud,("OK") 'Wait up to 6 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("JAP OK",13,10)

CIPSTART:
serout C.4,baud,("AT+CIPSTART=",34,"TCP",34,",",34,"184.106.153.149",34,",80",13,10)
'Send command string to ESP-01+CR+LF to access Thingspeak.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("CIPSTART OK",13,10)

CIPSEND:
serout C.4,baud,("AT+CIPSEND=45",13,10)
'Send AT+CIPSEND command+byte total+CR+LF to ESP-01 to advise Thingspeak to expect
'45 bytes of data. Note that the number of bytes advised must agree with the number 
'of bytes sent in the next serout command. The quotation marks and the commas don't  
'count, but everything else does. Count the bytes in the following serout command to
'see that they do total 45. Each time you change the length of the data sent, you
'must change the total in the AT+CIPSEND command string to agree.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("CIPSEND OK",13,10)

send_data:
serout C.4,baud,("GET /update?key=your Thingspeak write key&field1=",b5,b6,b7,13,10)
'Send write key+temperature+CR+LF to Thingspeak. Note that this transmission
'includes data for only Field 1. Add an additional field and data by adding &field2
'plus the data for as many fields as are available. Change the AT+CIPSEND command
'string to agree with the new byte total.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("DATASEND OK",13,10)

serin[3000],C.3,baud,("CLOSED") 'Wait up to 3 seconds to receive CLOSED. If CLOSED is
'not received, go to send_fail; otherwise proceed.
sertxd("CLOSED",13,10)

CWQAP2:
serout C.4,baud,("AT+CWQAP",13,10) 'Send disconnect from Wi-Fi command+CR+LF to ESP-01.
serin[3000,send_fail],C.3,baud,("OK") 'Wait up to 3 seconds to receive OK. If OK is
'not received, go to send_fail; otherwise proceed.
sertxd("QAP OK",13,10)

ESP_Off:
pause 1000 'Pause 1 second to allow ESP-01 to complete operations.
low CH_PD 'Disables ESP-01 module.

hold:
for w7 = 1 to 896 'Establish a for/next loop for 896 repetitions.
	pause 4000 'Pause 4 seconds.
next w7 'Next loop: 3585 seconds + 15 seconds for program execution = 60 minutes.

goto main

send_fail:
sertxd("SEND FAILED",13,10)
goto CWQAP2